import { CustomElement } from '../../../packages/core/src/index';
import { MDCTopAppBar } from '@material/top-app-bar';
import { bindable, containerless, customElement, inlineView } from 'aurelia-templating';

import '@material/top-app-bar/dist/mdc.top-app-bar.min.css';

const template = `<template>
    <header class.bind="classSet">
        <slot></slot>
    </header>
</template>`;

/**
 * Material Design Button
 * @see {@link https://material.io/develop/web/components/top-app-bar/}
 * @see {@link https://material-components-web.appspot.com/top-app-bar.html}
 *
 * @example
 * <mdc-top-app-bar>
 *   <mdc-top-app-bar-row>
 *     <mdc-top-app-bar-section>
 *       <mdc-top-app-bar-title>Top App Bar</mdc-top-app-bar-title>
 *     </mdc-top-app-bar-section>
 *   </mdc-top-app-bar-row>
 * </mdc-top-app-bar>
 */
@customElement('mdc-top-app-bar')
@inlineView(template)
@containerless
export class TopAppBar extends CustomElement {
    /**
     * @type {Boolean}
     */
    @bindable fixed = false;
    /**
     * @type {Boolean}
     */
    @bindable prominent = false;
    /**
     * @type {Boolean}
     */
    @bindable short = false;
    /**
     * @type {Boolean}
     */
    @bindable shortCollapsed = false;
    /**
     * Aurelia Attached Event
     */
    atached() {
        if (this.mdcElement) {
            this.mdcTopAppBar = new MDCTopAppBar(this.mdcElement);
        }
    }
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({
            'mdc-top-app-bar': true,
            'mdc-top-app-bar--fixed': this.fixed,
            'mdc-top-app-bar--prominent': this.prominent,
            'mdc-top-app-bar--short': this.short,
            'mdc-top-app-bar--short-collapsed': this.shortCollapsed
        });
    }
}

const templateRow = `<template>
    <div class.bind="classSet">
        <slot></slot>
    </div>
</template>`;

/**
 * Material Design Button
 * @see {@link https://material.io/develop/web/components/top-app-bar/}
 * @see {@link https://material-components-web.appspot.com/top-app-bar.html}
 *
 * @example
 * <mdc-top-app-bar-row>
 *   <mdc-top-app-bar-section>
 *     <mdc-top-app-bar-title>Top App Bar</mdc-top-app-bar-title>
 *   </mdc-top-app-bar-section>
 * </mdc-top-app-bar-row>
 */
@customElement('mdc-top-app-bar-row')
@inlineView(templateRow)
@containerless
export class TopAppBarRow extends CustomElement {
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({
            'mdc-top-app-bar__row': true
        });
    }
}

const templateSection = `<template>
    <span class.bind="classSet">
        <slot></slot>
    </span>
</template>`;

/**
 * Material Design Button
 * @see {@link https://material.io/develop/web/components/top-app-bar/}
 * @see {@link https://material-components-web.appspot.com/top-app-bar.html}
 *
 * @example
 * <mdc-top-app-bar-section>
 *   <mdc-top-app-bar-title>Top App Bar</mdc-top-app-bar-title>
 * </mdc-top-app-bar-section>
 */
@customElement('mdc-top-app-bar-section')
@inlineView(templateSection)
@containerless
export class TopAppBarSection extends CustomElement {
    /**
     * @type {Boolean}
     */
    @bindable alignEnd = false;
    /**
     * @type {Boolean}
     */
    @bindable alignStart = false;
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({
            'mdc-top-app-bar__section': true,
            'mdc-top-app-bar__section--align-end': this.alignEnd,
            'mdc-top-app-bar__section--align-start': this.alignStart
        });
    }
}

const templateTitle = `<template>
    <span class.bind="classSet">
        <slot></slot>
    </span>
</template>`;

/**
 * Material Design Button
 * @see {@link https://material.io/develop/web/components/top-app-bar/}
 * @see {@link https://material-components-web.appspot.com/top-app-bar.html}
 *
 * @example
 * <mdc-top-app-bar-title>Top App Bar</mdc-top-app-bar-title>
 */
@customElement('mdc-top-app-bar-title')
@inlineView(templateTitle)
@containerless
export class TopAppBarTitle extends CustomElement {
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({
            'mdc-top-app-bar__title': true
        });
    }
}
